@@ -54,17 +54,17 @@ AdaProjectPart::AdaProjectPart(TQObject *parent, const char *name, const TQStrin
 
     TDEAction *action;
     action = new TDEAction( i18n("&Build Project"), "make_tdevelop", Key_F8,
-                          this, TQT_SLOT(slotBuild()),
+                          this, TQ_SLOT(slotBuild()),
                           actionCollection(), "build_build" );
     action = new TDEAction( i18n("Execute Program"), "application-x-executable", 0,
-                          this, TQT_SLOT(slotExecute()),
+                          this, TQ_SLOT(slotExecute()),
                           actionCollection(), "build_execute" );
 
-    connect( core(), TQT_SIGNAL(projectConfigWidget(KDialogBase*)),
-             this, TQT_SLOT(projectConfigWidget(KDialogBase*)) );
+    connect( core(), TQ_SIGNAL(projectConfigWidget(KDialogBase*)),
+             this, TQ_SLOT(projectConfigWidget(KDialogBase*)) );
 
-    connect( core(), TQT_SIGNAL(configWidget(KDialogBase*)),
-             this, TQT_SLOT(configWidget(KDialogBase*)) );
+    connect( core(), TQ_SIGNAL(configWidget(KDialogBase*)),
+             this, TQ_SLOT(configWidget(KDialogBase*)) );
 
 //  m_widget = new AdaProjectWidget(this);
 
@@ -374,8 +374,8 @@ void AdaProjectPart::projectConfigWidget( KDialogBase * dlg )
     TQVBox *vbox;
     vbox = dlg->addVBoxPage(i18n("Ada Compiler"));
     AdaProjectOptionsDlg *w = new AdaProjectOptionsDlg(this, vbox);
-    connect( dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()) );
-    connect( dlg, TQT_SIGNAL(okClicked()), this, TQT_SLOT(loadProjectConfig()) );
+    connect( dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()) );
+    connect( dlg, TQ_SIGNAL(okClicked()), this, TQ_SLOT(loadProjectConfig()) );
 }
 
 void AdaProjectPart::loadProjectConfig( )
@@ -405,7 +405,7 @@ void AdaProjectPart::configWidget( KDialogBase * dlg )
     TQVBox *vbox;
     vbox = dlg->addVBoxPage(i18n("Ada Compiler"));
     AdaGlobalOptionsDlg *w = new AdaGlobalOptionsDlg(this, vbox);
-    connect( dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()) );
+    connect( dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()) );
 }
 
 KDevCompilerOptions *AdaProjectPart::createCompilerOptions(const TQString &name)
