@@ -44,7 +44,7 @@ class AddExistingFilesDialog : public AddExistingDlgBase
 public:
 	AddExistingFilesDialog( AutoProjectPart* part, AutoProjectWidget *widget, 
 	                        SubprojectItem* spitem, TargetItem* titem, TQWidget* parent = 0,
-	                        const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+	                        const char* name = 0, bool modal = false, WFlags fl = 0 );
 	~AddExistingFilesDialog();
 
 private:
