@@ -24,7 +24,7 @@ class SubprojectItem;
 
 class AddSubprojectDialog : public AddSubprojectDlgBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
