@@ -24,7 +24,7 @@ class EnvironmentVariablesWidget;
 
 class ConfigureOptionsWidget : public ConfigureOptionsWidgetBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
