@@ -35,12 +35,12 @@
 // Take the name prefix into account.
 #define yylex   TQMakelex
 
-#include "qmake_yacc.hpp"
+#include "qmake_yacc.h"
 
 /* User implementation prologue.  */
 
 
-/* Line 317 of lalr1.cc.  */
+/* Line 317 of lalr1.cpp.  */
 #line 45 "tqmake_yacc.cpp"
 
 #ifndef YY_
@@ -751,7 +751,7 @@ namespace TQMake
     break;
 
 
-    /* Line 675 of lalr1.cc.  */
+    /* Line 675 of lalr1.cpp.  */
 #line 756 "tqmake_yacc.cpp"
 	default: break;
       }
