@@ -10,7 +10,7 @@
 
 class EditorChooserWidget : public EditChooser
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
