@@ -13,7 +13,7 @@
 namespace VisualBoyAdvance {  
   class VisualBoyAdvancePart : public KDevPlugin
     {
-      Q_OBJECT
+      TQ_OBJECT
   
 	
 	public:
