@@ -82,13 +82,13 @@ bool TQDesignerDataBrowser::event( TQEvent* e )
 #endif
 	if ( e->type() == TQEvent::Show ) {
 	    if ( con ) {
-		TQSqlCursor* cursor = new TQSqlCursor( tbl, TRUE, con );
-		setSqlCursor( cursor, TRUE );
+		TQSqlCursor* cursor = new TQSqlCursor( tbl, true, con );
+		setSqlCursor( cursor, true );
 		setForm( frm );
 		refresh();
 		first();
 	    }
-	    return TRUE;
+	    return true;
 	}
 #if defined(DESIGNER)
     }
@@ -110,7 +110,7 @@ bool TQDesignerDataView::event( TQEvent* e )
 	if ( e->type() == TQEvent::Show ) {
 	    setForm( frm );
 	    readFields();
-	    return TRUE;
+	    return true;
 	}
 #if defined(DESIGNER)
     }
