@@ -166,7 +166,7 @@ void AddMethodDialog::accept()
 		int funEndLine, funEndColumn;
 		( *it ) ->getEndPosition( &funEndLine, &funEndColumn );
 		TQString access = accessID( *it );
-		TQPair<int, int> funEndPoint = tqMakePair( funEndLine, funEndColumn );
+		TQPair<int, int> funEndPoint = qMakePair( funEndLine, funEndColumn );
 
 		if ( !points.contains( access ) || points[ access ] < funEndPoint )
 		{
@@ -206,7 +206,7 @@ void AddMethodDialog::accept()
 			else
 			{
 			str.prepend( access + ":\n" );
-				points[ *it ] = tqMakePair( line - 1, 0 );
+				points[ *it ] = qMakePair( line - 1, 0 );
 				pt = points[ *it ]; // end of class declaration
 			}
 
