@@ -104,14 +104,14 @@ VariableWidget::VariableWidget(GDBController*  controller,
     topLayout->addItem(buttons);
 
 
-    connect( addButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotAddWatchVariable()) );
-    connect( evalButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotEvaluateExpression()) );
+    connect( addButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotAddWatchVariable()) );
+    connect( evalButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotEvaluateExpression()) );
 
-    connect( watchVarEditor_, TQT_SIGNAL(returnPressed()),
-             TQT_SLOT(slotEvaluateExpression()) );
+    connect( watchVarEditor_, TQ_SIGNAL(returnPressed()),
+             TQ_SLOT(slotEvaluateExpression()) );
 
-    connect(controller, TQT_SIGNAL(event(GDBController::event_t)),
-            varTree_,       TQT_SLOT(slotEvent(GDBController::event_t)));
+    connect(controller, TQ_SIGNAL(event(GDBController::event_t)),
+            varTree_,       TQ_SLOT(slotEvent(GDBController::event_t)));
 
 
     // Setup help items.
@@ -223,10 +223,10 @@ VariableTree::VariableTree(VariableWidget *parent,
     addColumn(i18n("Value"));
 //     setResizeMode(AllColumns);
 
-    connect( this, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
-             TQT_SLOT(slotContextMenu(TDEListView*, TQListViewItem*)) );
-    connect( this, TQT_SIGNAL(itemRenamed( TQListViewItem*, int, const TQString&)),
-             this, TQT_SLOT(slotItemRenamed( TQListViewItem*, int, const TQString&)));
+    connect( this, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+             TQ_SLOT(slotContextMenu(TDEListView*, TQListViewItem*)) );
+    connect( this, TQ_SIGNAL(itemRenamed( TQListViewItem*, int, const TQString&)),
+             this, TQ_SLOT(slotItemRenamed( TQListViewItem*, int, const TQString&)));
 }
 
 // **************************************************************************
@@ -1085,9 +1085,9 @@ VarItem::VarItem(TrimmableItem *parent,
       baseClassMember_(false),
       alive_(true)
 {
-    connect(this, TQT_SIGNAL(varobjNameChange(const TQString&, const TQString&)),
+    connect(this, TQ_SIGNAL(varobjNameChange(const TQString&, const TQString&)),
             varTree(),
-            TQT_SLOT(slotVarobjNameChanged(const TQString&, const TQString&)));
+            TQ_SLOT(slotVarobjNameChanged(const TQString&, const TQString&)));
 
 
     // User might have entered format together with expression: like
@@ -1130,9 +1130,9 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
   baseClassMember_(baseClassMember),
   alive_(true)
 {
-    connect(this, TQT_SIGNAL(varobjNameChange(const TQString&, const TQString&)),
+    connect(this, TQ_SIGNAL(varobjNameChange(const TQString&, const TQString&)),
             varTree(),
-            TQT_SLOT(slotVarobjNameChanged(const TQString&, const TQString&)));
+            TQ_SLOT(slotVarobjNameChanged(const TQString&, const TQString&)));
 
     expression_ = varobj["exp"].literal();
     varobjName_ = varobj["name"].literal();
