@@ -19,7 +19,7 @@ class SettingsDialog;
 
 class KDevQtImporter : public KDevPCSImporter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KDevQtImporter( TQObject* parent=0, const char* name=0, const TQStringList& args=TQStringList() );
