@@ -159,7 +159,7 @@ void PHPCodeCompletion::cursorPositionChanged(){
    }
 
    if (m_config->getCodeCompletion()) {
-      if (m_completionBoxShow == true) {
+      if (m_completionBoxShow) {
          return;
       }
 
@@ -204,7 +204,7 @@ bool PHPCodeCompletion::showCompletionBox(TQValueList<KTextEditor::CompletionEnt
             return false;
       }
       m_completionBoxShow = true;
-      m_codeInterface->showCompletionBox(list, max, FALSE);
+      m_codeInterface->showCompletionBox(list, max, false);
       return true;
    }
    return false;
@@ -218,7 +218,7 @@ bool PHPCodeCompletion::checkForStaticFunction(TQString line, int col) {
       return false;
 
    TQRegExp Class("([a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*)::([a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*|)");
-   Class.setCaseSensitive(FALSE);
+   Class.setCaseSensitive(false);
 
    if (Class.search(line) != -1) {
       TQString classname = Class.cap(1);
@@ -234,7 +234,7 @@ bool PHPCodeCompletion::checkForStaticFunction(TQString line, int col) {
 
          for (funcIt = funcList.begin(); funcIt != funcList.end(); ++funcIt) {
             FunctionDom nFunc = *funcIt;
-            if ((function.isEmpty() || nFunc->name().startsWith(function, FALSE)) && nFunc->isStatic()) {
+            if ((function.isEmpty() || nFunc->name().startsWith(function, false)) && nFunc->isStatic()) {
                KTextEditor::CompletionEntry e;
                e.prefix = nClass->name() + " ::";
                e.text = nFunc->name();
@@ -267,11 +267,11 @@ bool PHPCodeCompletion::checkForNew(TQString line, int col){
    kdDebug(9018)   << "checkForNew" << endl;
    TQValueList<KTextEditor::CompletionEntry> list;
 
-   if (line.find("new ", 0, FALSE) == -1)
+   if (line.find("new ", 0, false) == -1)
       return false;
 
    TQRegExp New("[& \t]*new[ \t]+([a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*|)");
-   New.setCaseSensitive(FALSE);
+   New.setCaseSensitive(false);
 
    if (New.search(line) != -1) {
       list = getClasses( New.cap(1) );
@@ -297,11 +297,11 @@ bool PHPCodeCompletion::checkForExtends(TQString line, int col){
    kdDebug(9018)   << "checkForExtends" << endl;
    TQValueList<KTextEditor::CompletionEntry> list;
 
-   if (line.find("extends", 0, FALSE) == -1)
+   if (line.find("extends", 0, false) == -1)
       return false;
 
    TQRegExp extends("[ \t]*extends[ \t]+([a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*|)");
-   extends.setCaseSensitive(FALSE);
+   extends.setCaseSensitive(false);
 
    if (extends.search(line) != -1) {
       list = getClasses(extends.cap(1));
@@ -362,7 +362,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getClasses(TQString
    ClassList::Iterator classIt;
    for (classIt = classList.begin(); classIt != classList.end(); ++classIt) {
       ClassDom nClass = *classIt;
-      if (name == NULL || name.isEmpty() || nClass->name().startsWith(name, FALSE)) {
+      if (name == NULL || name.isEmpty() || nClass->name().startsWith(name, false)) {
          KTextEditor::CompletionEntry e;
 
          TQStringList::Iterator it = added.find(nClass->name());
@@ -383,7 +383,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getFunctionsAndVars
    if (classname.isEmpty()) {
       TQValueList<FunctionCompletionEntry>::Iterator it;
       for( it = m_globalFunctions.begin(); it != m_globalFunctions.end(); ++it ) {
-         if((*it).text.startsWith(function, FALSE)){
+         if((*it).text.startsWith(function, false)){
             KTextEditor::CompletionEntry e;
             e = (*it);
             list.append(e);
@@ -393,7 +393,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getFunctionsAndVars
       FunctionList methodList = m_model->globalNamespace()->functionList();
       FunctionList::Iterator methodIt;
       for (methodIt = methodList.begin(); methodIt != methodList.end(); ++methodIt) {
-         if ((*methodIt)->name().startsWith(function, FALSE)){
+         if ((*methodIt)->name().startsWith(function, false)){
             KTextEditor::CompletionEntry e;
             e.text = (*methodIt)->name();
             ArgumentDom pArg = (*methodIt)->argumentList().first();
@@ -416,7 +416,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getFunctionsAndVars
       FunctionList::Iterator methodIt;
       for (methodIt = methodList.begin(); methodIt != methodList.end(); ++methodIt) {
          FunctionDom pMethod = *methodIt;
-         if (function.isEmpty() || pMethod->name().startsWith(function, FALSE)) {
+         if (function.isEmpty() || pMethod->name().startsWith(function, false)) {
             KTextEditor::CompletionEntry e;
             ArgumentDom arg = pMethod->argumentList().first();
 
@@ -430,7 +430,7 @@ TQValueList<KTextEditor::CompletionEntry> PHPCodeCompletion::getFunctionsAndVars
       VariableList::Iterator attrIt;
       for (attrIt = attrList.begin(); attrIt != attrList.end(); ++attrIt) {
          VariableDom pVar = *attrIt;
-         if (function.isEmpty() || pVar->name().startsWith(function, FALSE)) {
+         if (function.isEmpty() || pVar->name().startsWith(function, false)) {
             KTextEditor::CompletionEntry e;
             e.prefix = nClass->name() + " ::";
             e.text = pVar->name();
@@ -517,7 +517,7 @@ TQStringList PHPCodeCompletion::getArguments(TQString classname, TQString functi
 TQString PHPCodeCompletion::getCurrentClassName() {
    kdDebug(9018) << "getCurrentClassName" << endl;
    TQRegExp Class("^[ \t]*(abstract|final|)[ \t]*class[ \t]+([a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*)[ \t]*(extends[ \t]*([a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*))?.*$");
-   Class.setCaseSensitive(FALSE);
+   Class.setCaseSensitive(false);
 
    for(int i = m_currentLine; i >= 0; i--){
       TQString line = m_editInterface->textLine(i);
@@ -577,7 +577,7 @@ TQString PHPCodeCompletion::getClassName(TQString varName, TQString classname) {
 
    for(int i = m_currentLine; i >= 0; i--){
       TQString line = m_editInterface->textLine(i);
-      if (!line.isNull() && line.find(varName,0 , FALSE) != -1) {
+      if (!line.isNull() && line.find(varName,0 , false) != -1) {
 
          if (createmember.search(line) != -1) {
             TQString right = createmember.cap(1).stripWhiteSpace();
@@ -637,12 +637,12 @@ bool PHPCodeCompletion::checkForArgHint(TQString line, int col) {
    TQValueList<KTextEditor::CompletionEntry> list;
    TQStringList argsList;
 
-   if (m_argWidgetShow == true)
+   if (m_argWidgetShow)
       return false;
 
    if (line.find("::") != -1) {
       TQRegExp Static("([a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*)::([a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*)");
-      Static.setCaseSensitive(FALSE);
+      Static.setCaseSensitive(false);
 
       if (Static.search(line) != -1) {
          TQString classname = Static.cap(1);
