@@ -86,12 +86,12 @@ ImportDialog::ImportDialog(AppWizardPart *part, TQWidget *parent, const char *na
 
     infrastructureBox->setEnabled(false);
     setProjectType("c");
-    connect( name_edit, TQT_SIGNAL( textChanged ( const TQString & ) ), this, TQT_SLOT( slotProjectNameChanged( const TQString & ) ) );
+    connect( name_edit, TQ_SIGNAL( textChanged ( const TQString & ) ), this, TQ_SLOT( slotProjectNameChanged( const TQString & ) ) );
 //    scanAvailableVCS();
-    connect( fetchModuleButton, TQT_SIGNAL(clicked()),
-        this, TQT_SLOT(slotFetchModulesFromRepository()) );
-    connect(urlinput_edit, TQT_SIGNAL(urlSelected(const TQString& )), this, TQT_SLOT(dirChanged()));
-    connect(urlinput_edit, TQT_SIGNAL(returnPressed(const TQString& )), this, TQT_SLOT(dirChanged()));
+    connect( fetchModuleButton, TQ_SIGNAL(clicked()),
+        this, TQ_SLOT(slotFetchModulesFromRepository()) );
+    connect(urlinput_edit, TQ_SIGNAL(urlSelected(const TQString& )), this, TQ_SLOT(dirChanged()));
+    connect(urlinput_edit, TQ_SIGNAL(returnPressed(const TQString& )), this, TQ_SLOT(dirChanged()));
     slotProjectNameChanged( name_edit->text() );
 }
 
@@ -409,7 +409,7 @@ void ImportDialog::scanAutomakeProject(const TQString &dirName)
     // AC_DEFINE(VERSION, "5.6")
     TQRegExp ac_define("^AC_DEFINE\\s*\\(\\s*[^,]+,([^\\)]+)");
     TQRegExp version("(\\bversion\\b)");
-    version.setCaseSensitive(FALSE);
+    version.setCaseSensitive(false);
 
     TQTextStream cstream;
     // try for configure.in.in, configure.in, then configure.ac
@@ -417,7 +417,7 @@ void ImportDialog::scanAutomakeProject(const TQString &dirName)
     TQFile configIn(dirName+"/configure.in");
     TQFile configAc(dirName+"/configure.ac");
     if (configInIn.open(IO_ReadOnly)){
-        cstream.setDevice(TQT_TQIODEVICE(&configInIn));
+        cstream.setDevice(&configInIn);
         while (!cstream.atEnd()) {
             TQString line = cstream.readLine();
             if ( ac_init.search(line) >= 0){
@@ -437,11 +437,11 @@ void ImportDialog::scanAutomakeProject(const TQString &dirName)
     }
 
     if (configIn.open(IO_ReadOnly)){
-        cstream.setDevice(TQT_TQIODEVICE(&configIn));
+        cstream.setDevice(&configIn);
     }
     else{
         if (configAc.open(IO_ReadOnly)){
-            cstream.setDevice(TQT_TQIODEVICE(&configAc));
+            cstream.setDevice(&configAc);
         }
         else{
             return;
@@ -531,8 +531,8 @@ void ImportDialog::slotFetchModulesFromRepository()
     setCursor( KCursor::waitCursor() );
 //    setEnabled( false );
 
-    connect( vcs, TQT_SIGNAL(finishedFetching(TQString)),
-        this, TQT_SLOT(slotFinishedCheckout(TQString)) );
+    connect( vcs, TQ_SIGNAL(finishedFetching(TQString)),
+        this, TQ_SLOT(slotFinishedCheckout(TQString)) );
 
     //restore cursor if we can't fetch repository
     if ( !vcs->fetchFromRepository() )
