@@ -59,11 +59,11 @@ ClassViewWidget::ClassViewWidget( ClassViewPart * part )
 
     m_projectItem = 0;
 
-    connect( this, TQT_SIGNAL(returnPressed(TQListViewItem*)), this, TQT_SLOT(slotExecuted(TQListViewItem*)) );
-    connect( this, TQT_SIGNAL(executed(TQListViewItem*)), this, TQT_SLOT(slotExecuted(TQListViewItem*)) );
-    connect( m_part->core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(slotProjectOpened()) );
-    connect( m_part->core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(slotProjectClosed()) );
-    connect( m_part->core(), TQT_SIGNAL(languageChanged()), this, TQT_SLOT(slotProjectOpened()) );
+    connect( this, TQ_SIGNAL(returnPressed(TQListViewItem*)), this, TQ_SLOT(slotExecuted(TQListViewItem*)) );
+    connect( this, TQ_SIGNAL(executed(TQListViewItem*)), this, TQ_SLOT(slotExecuted(TQListViewItem*)) );
+    connect( m_part->core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(slotProjectOpened()) );
+    connect( m_part->core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(slotProjectClosed()) );
+    connect( m_part->core(), TQ_SIGNAL(languageChanged()), this, TQ_SLOT(slotProjectOpened()) );
 
     TQStringList lst;
     lst << i18n( "Group by Directories" ) << i18n( "Plain List" ) << i18n( "Java Like Mode" );
@@ -71,28 +71,28 @@ ClassViewWidget::ClassViewWidget( ClassViewPart * part )
     m_actionViewMode->setItems( lst );
     m_actionViewMode->setWhatsThis(i18n("<b>View mode</b><p>Class browser items can be grouped by directories, listed in a plain or java like view."));
 
-    m_actionNewClass = new TDEAction( i18n("New Class..."), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotNewClass()),
+    m_actionNewClass = new TDEAction( i18n("New Class..."), TDEShortcut(), this, TQ_SLOT(slotNewClass()),
 				    m_part->actionCollection(), "classview_new_class" );
     m_actionNewClass->setWhatsThis(i18n("<b>New class</b><p>Calls the <b>New Class</b> wizard."));
 	
-	m_actionCreateAccessMethods = new TDEAction( i18n("Create get/set Methods"), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotCreateAccessMethods()), m_part->actionCollection(), "classview_create_access_methods" );
+	m_actionCreateAccessMethods = new TDEAction( i18n("Create get/set Methods"), TDEShortcut(), this, TQ_SLOT(slotCreateAccessMethods()), m_part->actionCollection(), "classview_create_access_methods" );
 	
 	
-    m_actionAddMethod = new TDEAction( i18n("Add Method..."), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotAddMethod()),
+    m_actionAddMethod = new TDEAction( i18n("Add Method..."), TDEShortcut(), this, TQ_SLOT(slotAddMethod()),
 				    m_part->actionCollection(), "classview_add_method" );
     m_actionAddMethod->setWhatsThis(i18n("<b>Add method</b><p>Calls the <b>New Method</b> wizard."));
-    m_actionAddAttribute = new TDEAction( i18n("Add Attribute..."), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotAddAttribute()),
+    m_actionAddAttribute = new TDEAction( i18n("Add Attribute..."), TDEShortcut(), this, TQ_SLOT(slotAddAttribute()),
 				    m_part->actionCollection(), "classview_add_attribute" );
     m_actionAddAttribute->setWhatsThis(i18n("<b>Add attribute</b><p>Calls the <b>New Attribute</b> wizard."));
 
-    m_actionOpenDeclaration = new TDEAction( i18n("Open Declaration"), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotOpenDeclaration()),
+    m_actionOpenDeclaration = new TDEAction( i18n("Open Declaration"), TDEShortcut(), this, TQ_SLOT(slotOpenDeclaration()),
 				    m_part->actionCollection(), "classview_open_declaration" );
     m_actionOpenDeclaration->setWhatsThis(i18n("<b>Open declaration</b><p>Opens a file where the selected item is declared and jumps to the declaration line."));
-    m_actionOpenImplementation = new TDEAction( i18n("Open Implementation"), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotOpenImplementation()),
+    m_actionOpenImplementation = new TDEAction( i18n("Open Implementation"), TDEShortcut(), this, TQ_SLOT(slotOpenImplementation()),
 				    m_part->actionCollection(), "classview_open_implementation" );
     m_actionOpenImplementation->setWhatsThis(i18n("<b>Open implementation</b><p>Opens a file where the selected item is defined (implemented) and jumps to the definition line."));
 
-	m_actionFollowEditor = new TDEToggleAction( i18n("Follow Editor"), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotFollowEditor()), m_part->actionCollection(), "classview_follow_editor" );
+	m_actionFollowEditor = new TDEToggleAction( i18n("Follow Editor"), TDEShortcut(), this, TQ_SLOT(slotFollowEditor()), m_part->actionCollection(), "classview_follow_editor" );
 
     TDEConfig* config = m_part->instance()->config();
     config->setGroup( "General" );
@@ -218,12 +218,12 @@ void ClassViewWidget::slotProjectOpened( )
 
     m_projectDirectoryLength = m_projectDirectory.length() + 1;
 
-    connect( m_part->languageSupport(), TQT_SIGNAL(updatedSourceInfo()),
-	     this, TQT_SLOT(refresh()) );
-    connect( m_part->languageSupport(), TQT_SIGNAL(aboutToRemoveSourceInfo(const TQString&)),
-	     this, TQT_SLOT(removeFile(const TQString&)) );
-    connect( m_part->languageSupport(), TQT_SIGNAL(addedSourceInfo(const TQString&)),
-	     this, TQT_SLOT(insertFile(const TQString&)) );
+    connect( m_part->languageSupport(), TQ_SIGNAL(updatedSourceInfo()),
+	     this, TQ_SLOT(refresh()) );
+    connect( m_part->languageSupport(), TQ_SIGNAL(aboutToRemoveSourceInfo(const TQString&)),
+	     this, TQ_SLOT(removeFile(const TQString&)) );
+    connect( m_part->languageSupport(), TQ_SIGNAL(addedSourceInfo(const TQString&)),
+	     this, TQ_SLOT(insertFile(const TQString&)) );
 }
 
 void ClassViewWidget::slotProjectClosed( )
