@@ -18,7 +18,7 @@ class FileViewPart;
 
 class PartWidget : public TQVBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     PartWidget( FileViewPart *part, TQWidget *parent = 0 );
