@@ -51,10 +51,10 @@ AppOutputViewPart::AppOutputViewPart(TQObject *parent, const char *name, const T
     mainWindow()->embedOutputView(m_widget, i18n("Application"), i18n("Output of the executed user program"));
     hideView();
 
-    connect( core(), TQT_SIGNAL(stopButtonClicked(KDevPlugin*)),
-             this, TQT_SLOT(slotStopButtonClicked(KDevPlugin*)) );
-    connect(m_widget, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotProcessExited()));
-    connect(m_widget, TQT_SIGNAL(processExited(TDEProcess*)), TQT_SIGNAL(processExited()));
+    connect( core(), TQ_SIGNAL(stopButtonClicked(KDevPlugin*)),
+             this, TQ_SLOT(slotStopButtonClicked(KDevPlugin*)) );
+    connect(m_widget, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(slotProcessExited()));
+    connect(m_widget, TQ_SIGNAL(processExited(TDEProcess*)), TQ_SIGNAL(processExited()));
 }
 
 
