@@ -25,7 +25,7 @@ Implementation for the form displaying 'cvs log' output.
 */
 class CVSLogDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     CVSLogDialog( CvsService_stub *cvsService, TQWidget *parent=0, const char *name=0, int flags=0 );
