@@ -100,7 +100,7 @@ open_tmp_file (apr_file_t **fp,
 
   /* Open a unique file;  use APR_DELONCLOSE. */
   SVN_ERR (svn_io_open_unique_file (fp, &ignored_filename,
-                                    truepath, ".tmp", TRUE, pool));
+                                    truepath, ".tmp", true, pool));
 
   return SVN_NO_ERROR;
 }
@@ -135,7 +135,7 @@ apr_array_header_t* svn_sort__hash(apr_hash_t *ht,
   ary = apr_array_make(pool, apr_hash_count(ht), sizeof(svn_sort_item_type));
 
   /* loop over hash table and push all keys into the array */
-  sorted = TRUE;
+  sorted = true;
   prev_item = NULL;
   for (hi = apr_hash_first(pool, ht); hi; hi = apr_hash_next(hi))
 	{
@@ -251,13 +251,13 @@ void tdeio_svnProtocol::initNotifier(bool is_checkout, bool is_export, bool supp
 	ctx->notify_func = tdeio_svnProtocol::notify;
 	struct notify_baton *nb = ( struct notify_baton* )apr_palloc(spool, sizeof( struct notify_baton ) );
 	nb->master = this;
-	nb->received_some_change = FALSE;
-	nb->sent_first_txdelta = FALSE;
+	nb->received_some_change = false;
+	nb->sent_first_txdelta = false;
 	nb->is_checkout = is_checkout;
 	nb->is_export = is_export;
 	nb->suppress_final_line = suppress_final_line;
-	nb->in_external = FALSE;
-	nb->had_print_error = FALSE;
+	nb->in_external = false;
+	nb->had_print_error = false;
 	nb->pool = svn_pool_create (spool);
 
 	ctx->notify_baton = nb;
@@ -1185,7 +1185,7 @@ void tdeio_svnProtocol::svn_diff(const KURL & url1, const KURL& url2,int rev1, i
 		<< endl ;
 
 	apr_pool_t *subpool = svn_pool_create (pool);
-	apr_array_header_t *options = svn_cstring_split( "", "\t\r\n", TRUE, subpool );
+	apr_array_header_t *options = svn_cstring_split( "", "\t\r\n", true, subpool );
 
 // 	KURL nurl1 = url1;
 // 	KURL nurl2 = url2;
@@ -1801,7 +1801,7 @@ svn_error_t *tdeio_svnProtocol::clientCertSSLPrompt(
 // 		kdWarning()<<" Communication with dcop failed - fail to get certfile "<<endl;
 // 		return SVN_NO_ERROR;
 // 	}
-// 	if (replyType != TQSTRING_OBJECT_NAME_STRING) {
+// 	if (replyType != "TQString") {
 // 		kdWarning()<<" unexpected reply type "<<endl;
 // 		return SVN_NO_ERROR;
 // 	}
@@ -1918,7 +1918,7 @@ svn_error_t *tdeio_svnProtocol::commitLogPrompt( const char **log_msg, const cha
 		return err;
 	}
 
-	if ( replyType != TQSTRING_OBJECT_NAME_STRING ) {
+	if ( replyType != "TQString" ) {
 		kdWarning() << "Unexpected reply type" << endl;
 		svn_error_t *err = svn_error_create( SVN_ERR_EXTERNAL_PROGRAM, NULL,
 											 apr_pstrdup( pool, "Fail to call kded_kdevsvnd via DCOP." ) );
@@ -1959,7 +1959,7 @@ void tdeio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_acti
 			userstring = i18n( "Copied %1 " ).arg( path );
 			break;
 		case svn_wc_notify_delete: //delete
-			nb->received_some_change = TRUE;
+			nb->received_some_change = true;
 			userstring = i18n( "D %1" ).arg( path );
 			break;
 		case svn_wc_notify_restore : //restore
@@ -1981,11 +1981,11 @@ void tdeio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_acti
 				userstring=i18n("Skipped  %1.").arg( path );
 			break;
 		case svn_wc_notify_update_delete: //update_delete
-			nb->received_some_change = TRUE;
+			nb->received_some_change = true;
 			userstring=i18n( "D %1" ).arg( path );
 			break;
 		case svn_wc_notify_update_add: //update_add
-			nb->received_some_change = TRUE;
+			nb->received_some_change = true;
 			userstring=i18n( "A %1" ).arg( path );
 			break;
 		case svn_wc_notify_update_update: //update_update
@@ -1997,7 +1997,7 @@ void tdeio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_acti
 							&& ((prop_state == svn_wc_notify_state_inapplicable)
 								|| (prop_state == svn_wc_notify_state_unknown)
 								|| (prop_state == svn_wc_notify_state_unchanged)))) {
-					nb->received_some_change = TRUE;
+					nb->received_some_change = true;
 
 					if (kind == svn_node_file) {
 						if (content_state == svn_wc_notify_state_conflicted)
@@ -2073,10 +2073,10 @@ void tdeio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_acti
 				}
 			}
 			if (nb->in_external)
-				nb->in_external = FALSE;
+				nb->in_external = false;
 			break;
 		case svn_wc_notify_update_external: //update_external
-			nb->in_external = TRUE;
+			nb->in_external = true;
 			userstring = i18n("Fetching external item into %1." ).arg( path );
 			break;
 		case svn_wc_notify_status_completed: //status_completed
@@ -2104,7 +2104,7 @@ void tdeio_svnProtocol::notify(void *baton, const char *path, svn_wc_notify_acti
 			break;
 		case svn_wc_notify_commit_postfix_txdelta: //commit_postfix_txdelta
 			if (! nb->sent_first_txdelta) {
-				nb->sent_first_txdelta = TRUE;
+				nb->sent_first_txdelta = true;
 				userstring=i18n("Transmitting file data ");
 			} else {
 				userstring=".";
@@ -2186,7 +2186,7 @@ void tdeio_svnProtocol::wc_resolve( const KURL& wc, bool recurse ) {
 
 extern "C"
 {
-	KDE_EXPORT int kdemain(int argc, char **argv)    {
+	TDE_EXPORT int kdemain(int argc, char **argv)    {
 		TDEInstance instance( "tdeio_kdevsvn" );
 
 		kdDebug(9036) << "*** Starting tdeio_kdevsvn " << endl;
